==> igniteui-react-core-16.16.1.tgz: package/esm5/lib/ArcGISOnlineMapImageryDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { GeographicMapImageryDescriptionMetadata } from "./GeographicMapImageryDescriptionMetadata";
import { ArcGISOnlineMapImageryDescription } from "./ArcGISOnlineMapImageryDescription";
/**
 * @hidden
 */
var ArcGISOnlineMapImageryDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(ArcGISOnlineMapImageryDescriptionMetadata, _super);
    function ArcGISOnlineMapImageryDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    ArcGISOnlineMapImageryDescriptionMetadata.b = function (a) {
        if (ArcGISOnlineMapImageryDescriptionMetadata.a == null) {
            ArcGISOnlineMapImageryDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            ArcGISOnlineMapImageryDescriptionMetadata.c(ArcGISOnlineMapImageryDescriptionMetadata.a);
        }
        if (a.g(ArcGISOnlineMapImageryDescriptionMetadata.a)) {
            return;
        }
        a.s(ArcGISOnlineMapImageryDescriptionMetadata.a);
    };
    ArcGISOnlineMapImageryDescriptionMetadata.c = function (a) {
        GeographicMapImageryDescriptionMetadata.c(a);
        a.item("MapServerUri", "String");
        a.item("UserName", "String");
        a.item("Password", "String");
        a.item("UserToken", "String");
        a.item("IsMapPublic", "Boolean");
        a.item("DefaultTokenTimeout", "Number:int");
        a.item("TokenGenerationEndPoint", "String");
        a.item("RefererUri", "String");
    };
    ArcGISOnlineMapImageryDescriptionMetadata.d = function (a) {
        ArcGISOnlineMapImageryDescriptionMetadata.b(a);
        a.u("ArcGISOnlineMapImagery", function () { return new ArcGISOnlineMapImageryDescription(); });
        a.t("ArcGISOnlineMapImagery", ArcGISOnlineMapImageryDescriptionMetadata.a);
    };
    ArcGISOnlineMapImageryDescriptionMetadata.$t = markType(ArcGISOnlineMapImageryDescriptionMetadata, 'ArcGISOnlineMapImageryDescriptionMetadata');
    ArcGISOnlineMapImageryDescriptionMetadata.a = null;
    return ArcGISOnlineMapImageryDescriptionMetadata;
}(Base));
export { ArcGISOnlineMapImageryDescriptionMetadata };

==> igniteui-react-core-18.1.2.tgz: package/esm5/lib/ArcGISOnlineMapImageryDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { GeographicMapImageryDescriptionMetadata } from "./GeographicMapImageryDescriptionMetadata";
import { ArcGISOnlineMapImageryDescription } from "./ArcGISOnlineMapImageryDescription";
/**
 * @hidden
 */
var ArcGISOnlineMapImageryDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(ArcGISOnlineMapImageryDescriptionMetadata, _super);
    function ArcGISOnlineMapImageryDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    ArcGISOnlineMapImageryDescriptionMetadata.b = function (a) {
        if (ArcGISOnlineMapImageryDescriptionMetadata.a == null) {
            ArcGISOnlineMapImageryDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            ArcGISOnlineMapImageryDescriptionMetadata.c(ArcGISOnlineMapImageryDescriptionMetadata.a);
        }
        if (a.j(ArcGISOnlineMapImageryDescriptionMetadata.a)) {
            return;
        }
        a.y(ArcGISOnlineMapImageryDescriptionMetadata.a);
    };
    ArcGISOnlineMapImageryDescriptionMetadata.c = function (a) {
        GeographicMapImageryDescriptionMetadata.c(a);
        a.item("MapServerUri", "String");
        a.item("UserName", "String");
        a.item("Password", "String");
        a.item("UserToken", "String");
        a.item("IsMapPublic", "Boolean");
        a.item("DefaultTokenTimeout", "Number:int");
        a.item("TokenGenerationEndPoint", "String");
        a.item("RefererUri", "String");
    };
    ArcGISOnlineMapImageryDescriptionMetadata.d = function (a) {
        ArcGISOnlineMapImageryDescriptionMetadata.b(a);
        a.aa("ArcGISOnlineMapImagery", function () { return new ArcGISOnlineMapImageryDescription(); });
        a.z("ArcGISOnlineMapImagery", ArcGISOnlineMapImageryDescriptionMetadata.a);
    };
    ArcGISOnlineMapImageryDescriptionMetadata.$t = markType(ArcGISOnlineMapImageryDescriptionMetadata, 'ArcGISOnlineMapImageryDescriptionMetadata');
    ArcGISOnlineMapImageryDescriptionMetadata.a = null;
    return ArcGISOnlineMapImageryDescriptionMetadata;
}(Base));
export { ArcGISOnlineMapImageryDescriptionMetadata };
